clear
set linesize 100

use houseprice
codebook, compact

**# Bayesian model selection

bayes, rseed(92823) burnin(50000): regress saleprice soldage

bayes, saving(m0, replace) rseed(92823) burnin(80000): regress saleprice soldage
estimates store m0

bayes, saving(m1, replace) rseed(92823) burnin(80000): regress saleprice soldage lotarea ///
grlivarea garagearea wooddecksf totalbsmtsf 
estimates store m1

bayes, saving(m2, replace) rseed(92823) burnin(80000): regress saleprice soldage lotarea ///
grlivarea garagearea wooddecksf totalbsmtsf fullbath halfbath bedroomabvgr
estimates store m2

bayes, saving(m3, replace) rseed(92823) burnin(80000): regress saleprice soldage  lotarea ///
grlivarea garagearea wooddecksf totalbsmtsf fullbath halfbath bedroomabvgr overallqual overallcond ///
exterqual extercond kitchenqual 
estimates store m3

bayes, saving(m4, replace) rseed(92823) burnin(80000): regress saleprice soldage  lotarea ///
grlivarea garagearea wooddecksf totalbsmtsf fullbath halfbath bedroomabvgr overallqual overallcond ///
exterqual extercond kitchenqual i.foundation remodage i.fireplaces lotfrontage
estimates store m4

bayesgraph diagnostic {soldage}

bayesstats ic m*

bayestest model m1 m4

estimates restore m1
bayesstats summary, hpd


**# BMA
bmaregress saleprice soldage lotarea grlivarea garagearea wooddecksf ///
totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath halfbath ///
bedroomabvgr lotfrontage i.foundation remodage i.fireplaces, rseed(92823) saving(bma, replace)

bmacoefsample, rseed(92823) saving(bmacoefs1, replace)
bayesstats summary, hpd

bmagraph coefdensity lotfrontage i.foundation remodage i.fireplaces, combine

**## Postestimation
bmagraph pmp

bmastats models

bmagraph varmap
bmagraph varmap, equalwidth

bmastats jointness lotfrontage extercond
bmastats jointness i.fireplaces

**## bmaregress options
bmaregress saleprice soldage lotarea grlivarea ndflrsf garagearea wooddecksf ///
totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath halfbath ///
bedroomabvgr lotfrontage i.foundation remodage i.fireplaces, groupfv rseed(92823)  

bmaregress saleprice soldage (lotarea grlivarea ndflrsf garagearea wooddecksf totalbsmtsf) ///
(overallqual overallcond exterqual extercond kitchenqual) (fullbath halfbath bedroomabvgr) ///
lotfrontage i.foundation remodage i.fireplaces

bmaregress saleprice (lotfrontage, always) soldage lotarea grlivarea ndflrsf garagearea ///
wooddecksf totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath ///
halfbath bedroomabvgr i.foundation remodage i.fireplaces, rseed(92823) 

**# Priors
bmaregress saleprice soldage lotarea grlivarea ndflrsf garagearea wooddecksf ///
totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath halfbath ///
bedroomabvgr lotfrontage i.foundation remodage i.fireplaces, groupfv enumeration 

bmagraph msize

bmaregress saleprice soldage lotarea grlivarea ndflrsf garagearea wooddecksf ///
totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath halfbath ///
bedroomabvgr lotfrontage i.foundation remodage i.fireplaces, groupfv rseed(92823)

bmagraph msize


**## Model space
bmaregress saleprice soldage lotarea grlivarea ndflrsf garagearea wooddecksf ///
totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath halfbath ///
bedroomabvgr lotfrontage i.foundation remodage i.fireplaces, rseed(92823) saving(bma1, replace)
estimates store default

bmaregress saleprice soldage lotarea grlivarea ndflrsf garagearea wooddecksf ///
totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath halfbath ///
bedroomabvgr lotfrontage i.foundation remodage i.fireplaces, rseed(92823) ///
mprior(betabinomial 3) saving(bma2, replace)
estimates store msize3
bmagraph msize

bmaregress saleprice soldage lotarea grlivarea ndflrsf garagearea wooddecksf ///
totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath halfbath ///
bedroomabvgr lotfrontage i.foundation remodage i.fireplaces, rseed(92823) ///
mprior(uniform) saving(bma3, replace)
estimates store uniform
bmagraph msize

bmastats lps default msize3 uniform, compact

**## Zellner's g
bmaregress saleprice soldage lotarea grlivarea ndflrsf garagearea wooddecksf ///
totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath halfbath ///
bedroomabvgr lotfrontage i.foundation remodage i.fireplaces, rseed(92823) ///
gprior(fixed 3) saving(bma4, replace)
estimates store fixed3

bmaregress saleprice soldage lotarea grlivarea ndflrsf garagearea wooddecksf ///
totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath halfbath ///
bedroomabvgr lotfrontage i.foundation remodage i.fireplaces, rseed(92823) ///
gprior(betashrink 3 1) 


bmaregress saleprice soldage lotarea grlivarea ndflrsf garagearea wooddecksf ///
totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath halfbath ///
bedroomabvgr lotfrontage i.foundation remodage i.fireplaces, rseed(92823) ///
gprior(betashrink 3 1) saving(bma5, replace) mcmcsize(20000)
estimates store beta31

bmaregress saleprice soldage lotarea grlivarea ndflrsf garagearea wooddecksf ///
totalbsmtsf overallqual overallcond exterqual extercond kitchenqual fullbath halfbath ///
bedroomabvgr lotfrontage i.foundation remodage i.fireplaces, rseed(92823) ///
gprior(robust) saving(bma6, replace)
estimates store robust

bmastats lps default fixed3 beta31 robust, compact



**# Predictions
bmacoefsample, rseed(92823) saving(bmacoefs2, replace)

use houseprice2010
codebook, compact

bmapredict CrI_l CrI_u, cri hpd
generate coverage = saleprice > CrI_l & saleprice < CrI_u
summarize coverage

bmapredict lps, lps

bmapredict pmean, mean
generate mse = (saleprice-pmean)^2


